@@ -1,9 +1,8 @@
 /*
  * $RCSfile: client_tcp.c,v $
  *
- * Copyright (c) 1999-2005. Christian Heller. All rights reserved.
+ * Copyright (c) 1999-2005. Christian Heller and the CYBOP developers.
  *
- * This software is published under the GPL GNU General Public License.
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -23,7 +22,7 @@
  *
  * This file handles a client TCP socket.
  *
- * @version $Revision: 1.3 $ $Date: 2005/01/10 14:46:33 $ $Author: christian $
+ * @version $Revision: 1.6 $ $Date: 2005/03/30 14:15:42 $ $Author: christian $
  * @author Marcel Kiesling <makie2001@web.de>
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
@@ -31,17 +30,11 @@
 #ifndef CLIENT_TCP_SOURCE
 #define CLIENT_TCP_SOURCE
 
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <stdio.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <unistd.h>
-
+/*??
 char *pfad = "/home/cybop/object/socket/server_tcp.o";
 
-int main()
-{
+int main() {
+
     int socketnummer;
     int laenge;
     struct sockaddr_in adressstruktur;
@@ -71,12 +64,12 @@ int main()
     result=connect(socketnummer, (struct sockaddr *)&adressstruktur, laenge);
 
     if(result== -1) {
-	perror("huch der client hat einen Fehler");
-	exit(1);
+        perror("huch der client hat einen Fehler");
+        exit(1);
     }
     else{
-	printf("Verbindung zum Server hergestellt\n");
-	}
+        printf("Verbindung zum Server hergestellt\n");
+        }
 
     while (i<10) {
 
@@ -88,9 +81,11 @@ int main()
     i++;
     }
 
- close(socketnummer);
-return 0;
+    close(socketnummer);
+
+    return 0;
 }
+*/
 
 /* CLIENT_TCP_SOURCE */
 #endif
