@@ -1,9 +1,8 @@
 /*
  * $RCSfile: server_tcp.c,v $
  *
- * Copyright (c) 1999-2005. Christian Heller. All rights reserved.
+ * Copyright (c) 1999-2005. Christian Heller and the CYBOP developers.
  *
- * This software is published under the GPL GNU General Public License.
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -23,7 +22,7 @@
  *
  * This file handles a server TCP socket.
  *
- * @version $Revision: 1.3 $ $Date: 2005/01/10 14:46:33 $ $Author: christian $
+ * @version $Revision: 1.6 $ $Date: 2005/03/30 14:15:42 $ $Author: christian $
  * @author Marcel Kiesling <makie2001@web.de>
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
@@ -31,15 +30,8 @@
 #ifndef SERVER_TCP_SOURCE
 #define SERVER_TCP_SOURCE
 
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <stdio.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <unistd.h>
-
-int main()
-{
+/*??
+int main() {
 
     int server_socketnummer,client_socketnummer;
     int server_laenge,client_laenge;
@@ -68,14 +60,15 @@ int main()
 
     while(1) {
 
-    	read(client_socketnummer,&strg,300);
-	strcat(strg,hello);
-	write(client_socketnummer,&strg,300);
+        read(client_socketnummer,&strg,300);
+        strcat(strg,hello);
+        write(client_socketnummer,&strg,300);
 
     }
     close(client_socketnummer);
     close(server_socketnummer);
 }
+*/
 
 /* SERVER_TCP_SOURCE */
 #endif
