@@ -24,7 +24,7 @@
  *
  * From here all tests can be activated or deactivated.
  *
- * @version $Revision: 1.1 $ $Date: 2005/06/05 00:09:54 $ $Author: christian $
+ * @version $Revision: 1.15 $ $Date: 2005/08/11 22:33:47 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @author Rolf Holzmueller <rolf.holzmueller@gmx.de>
  */
@@ -33,12 +33,12 @@
 #define TEST_SOURCE
 
 #include <stdio.h>
-#include "../controller/converter/converter.c"
 #include "../globals/constants/structure_constants.c"
 #include "../globals/variables/variables.c"
-#include "../memory/accessor/compound_accessor.c"
-#include "../memory/array/array.c"
-#include "../memory/creator/integer_creator.c"
+#include "../memoriser/accessor/compound_accessor.c"
+#include "../memoriser/allocator.c"
+#include "../memoriser/array.c"
+#include "../memoriser/converter.c"
 
 /**
  * Tests the standard output and error stream.
@@ -106,19 +106,19 @@ void test_character_array_single_element() {
     int cs = 5;
 
     // Create character array.
-    create_array((void*) &c, (void*) &cs, (void*) CHARACTER_ARRAY);
+    allocate_array((void*) &c, (void*) &cs, (void*) CHARACTER_ARRAY);
 
-    set_character_array_elements(c, (void*) ZERO_NUMBER, (void*) LATIN_CAPITAL_LETTER_A_CHARACTER, (void*) LATIN_CAPITAL_LETTER_A_CHARACTER_COUNT);
-    set_character_array_elements(c, (void*) ONE_NUMBER, (void*) LATIN_CAPITAL_LETTER_B_CHARACTER, (void*) LATIN_CAPITAL_LETTER_B_CHARACTER_COUNT);
-    set_character_array_elements(c, (void*) TWO_NUMBER, (void*) LATIN_CAPITAL_LETTER_C_CHARACTER, (void*) LATIN_CAPITAL_LETTER_C_CHARACTER_COUNT);
-    set_character_array_elements(c, (void*) THREE_NUMBER, (void*) LINE_FEED_CONTROL_CHARACTER, (void*) LINE_FEED_CONTROL_CHARACTER_COUNT);
-    set_character_array_elements(c, (void*) FOUR_NUMBER, (void*) NULL_CONTROL_CHARACTER, (void*) NULL_CONTROL_CHARACTER_COUNT);
+    set_character_array_elements(c, (void*) NUMBER_0_INTEGER, (void*) LATIN_CAPITAL_LETTER_A_CHARACTER, (void*) CHARACTER_COUNT);
+    set_character_array_elements(c, (void*) NUMBER_1_INTEGER, (void*) LATIN_CAPITAL_LETTER_B_CHARACTER, (void*) CHARACTER_COUNT);
+    set_character_array_elements(c, (void*) NUMBER_2_INTEGER, (void*) LATIN_CAPITAL_LETTER_C_CHARACTER, (void*) CHARACTER_COUNT);
+    set_character_array_elements(c, (void*) NUMBER_3_INTEGER, (void*) LINE_FEED_CONTROL_CHARACTER, (void*) CHARACTER_COUNT);
+    set_character_array_elements(c, (void*) NUMBER_4_INTEGER, (void*) NULL_CONTROL_CHARACTER, (void*) CHARACTER_COUNT);
 
     // Print out array contents.
     fputs((char*) c, stdout);
 
     int i = 0;
-    char* catest = CHARACTER_NULL_POINTER;
+    char* catest = NULL_POINTER;
 
     while (1) {
 
@@ -134,7 +134,7 @@ void test_character_array_single_element() {
     }
 
     // Destroy character array.
-    destroy_array((void*) &c, (void*) &cs, (void*) CHARACTER_ARRAY);
+    deallocate_array((void*) &c, (void*) &cs, (void*) CHARACTER_ARRAY);
 }
 
 /**
@@ -149,7 +149,7 @@ void test_character_array_multiple_elements() {
     int ds = 22;
 
     // Create destination array.
-    create_array((void*) &d, (void*) &ds, (void*) CHARACTER_ARRAY);
+    allocate_array((void*) &d, (void*) &ds, (void*) CHARACTER_ARRAY);
 
     // The source array.
     char a[] = {'T', 'h', 'i', 's', ' ', 'i', 's', ' ', 'a', ' ', 't', 'e', 's', 't', '.', '\n', '\0'};
@@ -158,7 +158,7 @@ void test_character_array_multiple_elements() {
     int* ss = ssa;
 
     // The destination index to which to copy the source array.
-    set_character_array_elements(d, (void*) ZERO_NUMBER, (void*) s, (void*) ss);
+    set_character_array_elements(d, (void*) NUMBER_0_INTEGER, (void*) s, (void*) ss);
 
     fputs((char*) d, stdout);
 
@@ -168,14 +168,14 @@ void test_character_array_multiple_elements() {
     int ossa[] = {14};
     int* oss = ossa;
 
-    set_character_array_elements(d, (void*) EIGHT_NUMBER, (void*) os, (void*) oss);
+    set_character_array_elements(d, (void*) NUMBER_8_INTEGER, (void*) os, (void*) oss);
 
     fputs((char*) d, stdout);
 
     // The remove index.
     int ri = 12;
 
-    remove_character_array_elements(d, (void*) &ds, (void*) &ri, (void*) SEVEN_NUMBER);
+    remove_character_array_elements(d, (void*) &ds, (void*) &ri, (void*) NUMBER_7_INTEGER);
 
     fputs((char*) d, stdout);
 
@@ -183,7 +183,7 @@ void test_character_array_multiple_elements() {
     // including two places for new line '\n' and c string termination '\0'.
     int ns = 15;
 
-    resize_array((void*) &d, (void*) &ns, (void*) CHARACTER_ARRAY);
+    reallocate_array((void*) &d, (void*) &ns, (void*) &ns, (void*) CHARACTER_ARRAY);
 
     fputs((char*) d, stdout);
 
@@ -191,12 +191,12 @@ void test_character_array_multiple_elements() {
     void* r = NULL_POINTER;
 
     // Test getting a reference.
-    get_character_array_elements(d, (void*) EIGHT_NUMBER, (void*) &r);
+    get_character_array_elements(d, (void*) NUMBER_8_INTEGER, (void*) &r);
 
     fputs((char*) r, stdout);
 
     // Destroy destination array.
-    destroy_array((void*) &d, (void*) &ns, (void*) CHARACTER_ARRAY);
+    deallocate_array((void*) &d, (void*) &ns, (void*) CHARACTER_ARRAY);
 }
 
 /**
@@ -211,30 +211,30 @@ void test_pointer_return() {
 
     // The character array (including new line and null termination character).
     void* c = NULL_POINTER;
-    int* cs = INTEGER_NULL_POINTER;
+    int* cs = NULL_POINTER;
 
     // Create character array.
     c = (void*) "Hello World!";
-    create_integer((void*) &cs);
+    allocate((void*) &cs, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
     *cs = 13;
 
     // THIS is the important part of the test.
     // A simple null pointer can be declared and passed to a procedure (as reference &).
     // The procedure can then dereference the pointer (*parameter) and store the result.
     // Since this works, one can avoid allocating extra local result variables,
-    // and use just a null pointer to initialize the result variable.
+    // and use just a null pointer to initialise the result variable.
 
     // The result array.
     void* r = NULL_POINTER;
 
     // Get character from character array.
-    get_array_elements(c, (void*) SIX_NUMBER, (void*) &r, (void*) CHARACTER_ARRAY);
+    get_array_elements(c, (void*) NUMBER_6_INTEGER, (void*) &r, (void*) CHARACTER_ARRAY);
 
     // Print result (character array).
     fprintf(stderr, "r: %s\n", (char*) r);
 
     // Destroy character array.
-    destroy_integer((void*) &cs);
+    deallocate((void*) &cs, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
 }
 
 /**
@@ -255,16 +255,16 @@ void test_pointer_array() {
     fprintf(stderr, "c: %s\n", (char*) c);
 
     // The pointer array.
-    void** p = POINTER_NULL_POINTER;
+    void** p = &NULL_POINTER;
     int ps = 1;
 
     // Create pointer array.
-    create_array((void*) &p, (void*) &ps, (void*) POINTER_ARRAY);
+    allocate_array((void*) &p, (void*) &ps, (void*) POINTER_ARRAY);
 
     fprintf(stderr, "p: %i\n", p);
 
     // The result array.
-    void** r = NULL_POINTER;
+    void** r = &NULL_POINTER;
 
     //
     // Testing.
@@ -275,13 +275,13 @@ void test_pointer_array() {
 
     // Set character array in pointer array.
     // Hand over character array as reference, because pointer array is expected!
-    set_array_elements(p, (void*) ZERO_NUMBER, (void*) &c, (void*) ONE_NUMBER, (void*) POINTER_ARRAY);
+    set_array_elements(p, (void*) NUMBER_0_INTEGER, (void*) &c, (void*) NUMBER_1_INTEGER, (void*) POINTER_ARRAY);
 
     fprintf(stderr, "p[0] after set: %i\n", p[0]);
     fprintf(stderr, "p[1] after set: %i\n", p[1]);
 
     // Get character array from pointer array.
-    get_array_elements(p, (void*) ZERO_NUMBER, (void*) &r, (void*) POINTER_ARRAY);
+    get_array_elements(p, (void*) NUMBER_0_INTEGER, (void*) &r, (void*) POINTER_ARRAY);
 
     // Print result (character array).
     fprintf(stderr, "r pointer: %i\n", *r);
@@ -292,7 +292,7 @@ void test_pointer_array() {
     //
 
     // Destroy pointer array.
-    destroy_array((void*) &p, (void*) &ps, (void*) POINTER_ARRAY);
+    deallocate_array((void*) &p, (void*) &ps, (void*) POINTER_ARRAY);
 }
 
 /**
@@ -319,7 +319,7 @@ void test_file_read() {
     // The file name count.
     int fnc = 26;
 
-    create_array((void*) &a, (void*) &CHARACTER_ARRAY, (void*) &as);
+    allocate_array((void*) &a, (void*) &CHARACTER_ARRAY, (void*) &as);
 //??    read_file((void*) &a, (void*) &as, (void*) &ac, (void*) &fn, (void*) &fnc);
 
     fprintf(stderr, "a: %i\n", a);
@@ -345,7 +345,7 @@ void test_file_read() {
         j++;
     }
 
-    destroy_array((void*) &a, (void*) &CHARACTER_ARRAY, (void*) &as);
+    deallocate_array((void*) &a, (void*) &CHARACTER_ARRAY, (void*) &as);
 */
 }
 
@@ -437,7 +437,7 @@ void test_integer_parser() {
     int dis = -1;
 
     parse((void*) &di, (void*) &dic, (void*) &dis, (void*) &ss, (void*) &ssc,
-        (void*) &INTEGER_ABSTRACTION, (void*) &INTEGER_ABSTRACTION_COUNT);
+        (void*) &INTEGER_VECTOR_ABSTRACTION, (void*) &INTEGER_VECTOR_ABSTRACTION_COUNT);
 
     fprintf(stderr, "Parsed source string results in destination integer: %i\n", di);
 
@@ -451,15 +451,15 @@ void test_integer_parser() {
     int dss = 0;
 
     // Create destination string.
-    create_array((void*) &ds, (void*) &CHARACTER_ARRAY, (void*) &dss);
+    allocate_array((void*) &ds, (void*) &CHARACTER_ARRAY, (void*) &dss);
 
-    serialize((void*) &ds, (void*) &dsc, (void*) &dss, (void*) &si, (void*) &sic,
-        (void*) &INTEGER_ABSTRACTION, (void*) &INTEGER_ABSTRACTION_COUNT);
+    serialise((void*) &ds, (void*) &dsc, (void*) &dss, (void*) &si, (void*) &sic,
+        (void*) &INTEGER_VECTOR_ABSTRACTION, (void*) &INTEGER_VECTOR_ABSTRACTION_COUNT);
 
-    fprintf(stderr, "Serialized source integer results in destination string: %s\n", ds);
+    fprintf(stderr, "Serialised source integer results in destination string: %s\n", ds);
 
     // Destroy destination string.
-    destroy_array((void*) &ds, (void*) &CHARACTER_ARRAY, (void*) &dss);
+    deallocate_array((void*) &ds, (void*) &CHARACTER_ARRAY, (void*) &dss);
 */
 }
 
@@ -474,7 +474,7 @@ void test_integer_parser() {
  * @param p1 the knowledge model count
  * @param level the level for the tree
  */
-void test_knowledge_model(const void* p0, const void* p1, int level) {
+void test_knowledge_model(void* p0, void* p1, int level) {
 
     fputs("Test knowledge model:\n", stdout);
 
@@ -500,21 +500,21 @@ void test_knowledge_model(const void* p0, const void* p1, int level) {
         // The loop index.
         int i = 0;
         // The element name.
-        void** n = POINTER_NULL_POINTER;
-        void** nc = POINTER_NULL_POINTER;
-        void** ns = POINTER_NULL_POINTER;
+        void** n = &NULL_POINTER;
+        void** nc = &NULL_POINTER;
+        void** ns = &NULL_POINTER;
         // The element abstraction.
-        void** a = POINTER_NULL_POINTER;
-        void** ac = POINTER_NULL_POINTER;
-        void** as = POINTER_NULL_POINTER;
+        void** a = &NULL_POINTER;
+        void** ac = &NULL_POINTER;
+        void** as = &NULL_POINTER;
         // The element model.
-        void** m = POINTER_NULL_POINTER;
-        void** mc = POINTER_NULL_POINTER;
-        void** ms = POINTER_NULL_POINTER;
+        void** m = &NULL_POINTER;
+        void** mc = &NULL_POINTER;
+        void** ms = &NULL_POINTER;
         // The element details.
-        void** d = POINTER_NULL_POINTER;
-        void** dc = POINTER_NULL_POINTER;
-        void** ds = POINTER_NULL_POINTER;
+        void** d = &NULL_POINTER;
+        void** dc = &NULL_POINTER;
+        void** ds = &NULL_POINTER;
         // The comparison result.
         int r = 0;
 
@@ -571,7 +571,7 @@ void test_knowledge_model(const void* p0, const void* p1, int level) {
 
             if (r != 1) {
 
-                compare_arrays((void*) *a, (void*) *ac, (void*) STRING_ABSTRACTION, (void*) STRING_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+                compare_arrays((void*) *a, (void*) *ac, (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
                 if (r == 1) {
 
@@ -583,7 +583,7 @@ void test_knowledge_model(const void* p0, const void* p1, int level) {
 
             if (r != 1) {
 
-                compare_arrays((void*) *a, (void*) *ac, (void*) INTEGER_ABSTRACTION, (void*) INTEGER_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+                compare_arrays((void*) *a, (void*) *ac, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
                 if (r == 1) {
 
@@ -599,21 +599,21 @@ void test_knowledge_model(const void* p0, const void* p1, int level) {
             }
 
             // Reset element name.
-            n = POINTER_NULL_POINTER;
-            nc = POINTER_NULL_POINTER;
-            ns = POINTER_NULL_POINTER;
+            n = NULL_POINTER;
+            nc = NULL_POINTER;
+            ns = NULL_POINTER;
             // Reset element abstraction.
-            a = POINTER_NULL_POINTER;
-            ac = POINTER_NULL_POINTER;
-            as = POINTER_NULL_POINTER;
+            a = NULL_POINTER;
+            ac = NULL_POINTER;
+            as = NULL_POINTER;
             // Reset element model.
-            m = POINTER_NULL_POINTER;
-            mc = POINTER_NULL_POINTER;
-            ms = POINTER_NULL_POINTER;
+            m = NULL_POINTER;
+            mc = NULL_POINTER;
+            ms = NULL_POINTER;
             // Reset element details.
-            d = POINTER_NULL_POINTER;
-            dc = POINTER_NULL_POINTER;
-            ds = POINTER_NULL_POINTER;
+            d = NULL_POINTER;
+            dc = NULL_POINTER;
+            ds = NULL_POINTER;
             // Reset comparison result.
             r = 0;
 
@@ -622,7 +622,7 @@ void test_knowledge_model(const void* p0, const void* p1, int level) {
 
     } else {
 
-        fputs("ERROR: Could not test knowledge model. The knowledge model is null.", stdout);
+        fputs("ERROR: Could not test knowledge model. The knowledge model is null.\n", stdout);
     }
 }
 
@@ -635,18 +635,18 @@ void test_knowledge_model(const void* p0, const void* p1, int level) {
  */
 void test_compound(void* comp, int* comp_count, int* index) {
 
-    void** n = POINTER_NULL_POINTER;
-    void** nc = POINTER_NULL_POINTER;
-    void** ns = POINTER_NULL_POINTER;
-    void** a = POINTER_NULL_POINTER;
-    void** ac = POINTER_NULL_POINTER;
-    void** as = POINTER_NULL_POINTER;
-    void** m = POINTER_NULL_POINTER;
-    void** mc = POINTER_NULL_POINTER;
-    void** ms = POINTER_NULL_POINTER;
-    void** d = POINTER_NULL_POINTER;
-    void** dc = POINTER_NULL_POINTER;
-    void** ds = POINTER_NULL_POINTER;
+    void** n = &NULL_POINTER;
+    void** nc = &NULL_POINTER;
+    void** ns = &NULL_POINTER;
+    void** a = &NULL_POINTER;
+    void** ac = &NULL_POINTER;
+    void** as = &NULL_POINTER;
+    void** m = &NULL_POINTER;
+    void** mc = &NULL_POINTER;
+    void** ms = &NULL_POINTER;
+    void** d = &NULL_POINTER;
+    void** dc = &NULL_POINTER;
+    void** ds = &NULL_POINTER;
 
     get_compound_element_name_by_index(comp, comp_count, index,
         &n, &nc, &ns);
